embassy-stm32

Crates

git

Versions

stm32h755bi-cm7

Flavors

WWDG2

Struct WWDG2 

pub struct WWDG2 { /* private fields */ }
WWDG2 peripheral

Implementations

Source

impl WWDG2

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.